@@ -6,7 +6,7 @@ import time
 import urllib.parse
 import warnings
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Literal, Optional, Union
 
 from . import constants
 from .hf_api import whoami
@@ -39,10 +39,8 @@ class OAuthOrgInfo:
             Whether the org has a payment method set up. Hugging Face field.
         role_in_org (`Optional[str]`, *optional*):
             The user's role in the org. Hugging Face field.
-        pending_sso (`Optional[bool]`, *optional*):
-            Indicates if the user granted the OAuth app access to the org but didn't complete SSO. Hugging Face field.
-        missing_mfa (`Optional[bool]`, *optional*):
-            Indicates if the user granted the OAuth app access to the org but didn't complete MFA. Hugging Face field.
+        security_restrictions (`Optional[list[Literal["ip", "token-policy", "mfa", "sso"]]]`, *optional*):
+            Array of security restrictions that the user hasn't completed for this org. Possible values: "ip", "token-policy", "mfa", "sso". Hugging Face field.
     """
 
     sub: str
@@ -52,8 +50,7 @@ class OAuthOrgInfo:
     is_enterprise: bool
     can_pay: Optional[bool] = None
     role_in_org: Optional[str] = None
-    pending_sso: Optional[bool] = None
-    missing_mfa: Optional[bool] = None
+    security_restrictions: Optional[list[Literal["ip", "token-policy", "mfa", "sso"]]] = None
 
 
 @dataclass
@@ -82,7 +79,7 @@ class OAuthUserInfo:
             Whether the user is a pro user. Hugging Face field.
         can_pay (`Optional[bool]`, *optional*):
             Whether the user has a payment method set up. Hugging Face field.
-        orgs (`Optional[List[OrgInfo]]`, *optional*):
+        orgs (`Optional[list[OrgInfo]]`, *optional*):
             List of organizations the user is part of. Hugging Face field.
     """
 
@@ -96,7 +93,7 @@ class OAuthUserInfo:
     website: Optional[str]
     is_pro: bool
     can_pay: Optional[bool]
-    orgs: Optional[List[OAuthOrgInfo]]
+    orgs: Optional[list[OAuthOrgInfo]]
 
 
 @dataclass
@@ -193,7 +190,7 @@ def attach_huggingface_oauth(app: "fastapi.FastAPI", route_prefix: str = "/"):
 
 def parse_huggingface_oauth(request: "fastapi.Request") -> Optional[OAuthInfo]:
     """
-    Returns the information from a logged in user as a [`OAuthInfo`] object.
+    Returns the information from a logged-in user as a [`OAuthInfo`] object.
 
     For flexibility and future-proofing, this method is very lax in its parsing and does not raise errors.
     Missing fields are set to `None` without a warning.
@@ -221,8 +218,7 @@ def parse_huggingface_oauth(request: "fastapi.Request") -> Optional[OAuthInfo]:
                 is_enterprise=org.get("isEnterprise"),
                 can_pay=org.get("canPay"),
                 role_in_org=org.get("roleInOrg"),
-                pending_sso=org.get("pendingSSO"),
-                missing_mfa=org.get("missingMFA"),
+                security_restrictions=org.get("securityRestrictions"),
             )
             for org in orgs_data
         ]
@@ -310,7 +306,7 @@ def _add_oauth_routes(app: "fastapi.FastAPI", route_prefix: str) -> None:
             target_url = request.query_params.get("_target_url")
 
             # Build redirect URI with the same query params as before and bump nb_redirects count
-            query_params: Dict[str, Union[int, str]] = {"_nb_redirects": nb_redirects + 1}
+            query_params: dict[str, Union[int, str]] = {"_nb_redirects": nb_redirects + 1}
             if target_url:
                 query_params["_target_url"] = target_url
 
@@ -410,12 +406,12 @@ def _get_redirect_target(request: "fastapi.Request", default_target: str = "/")
     return request.query_params.get("_target_url", default_target)
 
 
-def _get_mocked_oauth_info() -> Dict:
+def _get_mocked_oauth_info() -> dict:
     token = get_token()
     if token is None:
         raise ValueError(
             "Your machine must be logged in to HF to debug an OAuth app locally. Please"
-            " run `huggingface-cli login` or set `HF_TOKEN` as environment variable "
+            " run `hf auth login` or set `HF_TOKEN` as environment variable "
             "with one of your access token. You can generate a new token in your "
             "settings page (https://huggingface.co/settings/tokens)."
         )
@@ -453,7 +449,7 @@ def _get_mocked_oauth_info() -> Dict:
     }
 
 
-def _get_oauth_uris(route_prefix: str = "/") -> Tuple[str, str, str]:
+def _get_oauth_uris(route_prefix: str = "/") -> tuple[str, str, str]:
     route_prefix = route_prefix.strip("/")
     if route_prefix:
         route_prefix = f"/{route_prefix}"
